@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *  Contact the author at:
  *              Jens Berger
@@ -231,7 +231,7 @@ char *strlwr(char *String)
     char TmpC;
 
     for (Bufptr = String; (TmpC = *Bufptr); Bufptr++)
-        *Bufptr = tolower(TmpC);
+        *Bufptr = tolower((unsigned char)TmpC);
 
     return (String);
 }
@@ -291,10 +291,10 @@ int strcasecmp(const char *a, const char *b)
         aa = *a++;
         bb = *b++;
     }
-    while (aa && (tolower(aa) == tolower(bb)));
+    while (aa && (tolower((unsigned char)aa) == tolower((unsigned char)bb)));
     /* bb != 0 is implicit */
 
-    return (tolower(aa) - tolower(bb));
+    return (tolower((unsigned char)aa) - tolower((unsigned char)bb));
 }
 #endif
 
@@ -367,7 +367,7 @@ int strafter(const char *Str, const char *Cmp)
  *
  */
 
-int strinfront(char *Str, char *Cmp)
+int strinfront(const char *Str, const char *Cmp)
 {
     int CmpLen;
 
@@ -685,7 +685,7 @@ int PushFileName(const char *Name, struct Stack *stack)
 }
 
 
-int PushFile(char *Name, FILE * fh, struct Stack *stack)
+int PushFile(const char *Name, FILE * fh, struct Stack *stack)
 {
     struct FileNode *fn;
 
@@ -718,9 +718,10 @@ char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
     {
         do
         {
-            if ((Retval = fgets(Dest, (int) len, fn->fh)))
-            {
-                fn->Line++;
+            Retval = fgets(Dest, (int)len, fn->fh);
+            if (Retval) {
+                if (Retval[strlen(Retval)-1] == '\n')
+                    fn->Line++;
                 break;
             }
 
@@ -735,10 +736,10 @@ char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
     return (Retval);
 }
 
-char *CurStkName(struct Stack *stack)
+const char *CurStkName(struct Stack *stack)
 {
     struct FileNode *fn;
-    static char *LastName = "";
+    static const char *LastName = "";
 
     if (PseudoInName && (stack->Used <= 1))
         return (PseudoInName);
